/********************************************************************************
 *Copyright 2011 - 2016, Siglent Technologies, Corporation. All Rights Reserved.*
 ********************************************************************************/
/****************************************************************************
 * sds
 * Title:    sds.h
 * Purpose:  SDS2000X+ IVI-C instrument driver declarations.
 ****************************************************************************/
#ifndef __SDS_HEADER
#define __SDS_HEADER

#include <ivi.h>
#include <iviscope.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif
/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/
/*sds.dll version for SDS2000X+ based on IVI-C*/
#define SDS_MAJOR_VERSION                1
#define SDS_MINOR_VERSION                0
/* IVI-4.1 IviScope class specification*/
#define SDS_CLASS_SPEC_MAJOR_VERSION     4
#define SDS_CLASS_SPEC_MINOR_VERSION     1

#define SDS_SUPPORTED_INSTRUMENT_MODELS  "SDS2000X+"
#define SDS_DRIVER_VENDOR                "Siglent Technologies"
#ifdef	_IVI_mswin64_
#define SDS_DRIVER_DESCRIPTION           "Description:Digital Storage Oscilloscope.[Compiled for 64-bit.]"
#else
#define SDS_DRIVER_DESCRIPTION           "Description:Digital Storage Oscilloscope."
#endif
/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/
/*-----------------------------------------------------------------------
*- Instrument-Specific Attributes -------------------------------------*
-----------------------------------------------------------------------*/
/*- Acquisition Sub-system -*/
#define SDS_ATTR_CHANNEL_COUNT                  IVI_ATTR_CHANNEL_COUNT                 /* ViInt32,  read-only  */
#define SDS_ATTR_INITIATE_CONTINUOUS            IVISCOPE_ATTR_INITIATE_CONTINUOUS      /* ViBoolean: VI_TRUE/VI_FALSE means RUN/STOP the instrument*/
#define SDS_ATTR_INTERPOLATION                  IVISCOPE_ATTR_INTERPOLATION            /* ViInt32: {SDS_VAL_SINE_X|SDS_VAL_LINEAR}*/
#define SDS_ATTR_NUM_AVERAGES     /*unsupported by SDS2000X+*/    IVISCOPE_ATTR_NUM_AVERAGES             /* ViInt32 {4|16|32|64|128|256|512|1024}*/
#define SDS_ATTR_NUM_ENVELOPES    /*unsupported by SDS2000X+*/    IVISCOPE_ATTR_NUM_ENVELOPES            /* ViInt32 */
#define SDS_ATTR_SAMPLE_MODE      /*unsupported by SDS2000X+*/    IVISCOPE_ATTR_SAMPLE_MODE              /* ViInt32, Read-only */
#define SDS_ATTR_HORZ_TIME_PER_RECORD           IVISCOPE_ATTR_HORZ_TIME_PER_RECORD     /* ViReal64: [2E-10, 1E+3],default unit:s/div*/
#define SDS_ATTR_HORZ_MIN_NUM_PTS /*unsupported by SDS2000X+*/   IVISCOPE_ATTR_HORZ_MIN_NUM_PTS         /* ViInt32 */
#define SDS_ATTR_HORZ_RECORD_LENGTH             IVISCOPE_ATTR_HORZ_RECORD_LENGTH       /* ViInt32, Read-only  */
#define SDS_ATTR_ACQUISITION_START_TIME         IVISCOPE_ATTR_ACQUISITION_START_TIME   /* ViReal64: [-5000div*timebase, 5*timebase] */
#define SDS_ATTR_HORZ_SAMPLE_RATE               IVISCOPE_ATTR_HORZ_SAMPLE_RATE         /* ViReal64, Read-only */
#define SDS_ATTR_ACQUISITION_TYPE               IVISCOPE_ATTR_ACQUISITION_TYPE         /* ViInt32: {SDS_VAL_NORMAL|SDS_VAL_PEAK_DETECT} */
/*- Channel Sub-system -*/
#define SDS_ATTR_CHANNEL_ENABLED                IVISCOPE_ATTR_CHANNEL_ENABLED          /* ViBoolean, Multi-channel */
#define SDS_ATTR_PROBE_ATTENUATION              IVISCOPE_ATTR_PROBE_ATTENUATION        /* ViReal64, Multi-channel. */
#define SDS_ATTR_PROBE_SENSE_VALUE              IVISCOPE_ATTR_PROBE_SENSE_VALUE        /* ViReal64, Multi-channel, Read-only */
#define SDS_ATTR_VERTICAL_RANGE                 IVISCOPE_ATTR_VERTICAL_RANGE           /* ViReal64, Multi-channel, volts,
                                                                                        {5e-04|1e-03|2e-03|5e-3|1e-2|2e-2|5e-2|1e-1|2e-1|5e-1|1e+0|2e+0|5e+0|1e+1} */
#define SDS_ATTR_VERTICAL_OFFSET                IVISCOPE_ATTR_VERTICAL_OFFSET          /* ViReal64, Multi-channel, volts */
#define SDS_ATTR_VERTICAL_COUPLING              IVISCOPE_ATTR_VERTICAL_COUPLING        /* ViInt32, Multi-channel, {SDS_VAL_AC|SDS_VAL_DC|SDS_VAL_GND}*/
#define SDS_ATTR_MAX_INPUT_FREQUENCY            IVISCOPE_ATTR_MAX_INPUT_FREQUENCY      /* ViReal64, multi-Channel,Bindwidth (0,1e+38)hertz */
#define SDS_ATTR_INPUT_IMPEDANCE                IVISCOPE_ATTR_INPUT_IMPEDANCE          /* ViReal64, multi-channel,{50|100000}ohms */
/*- Trigger Sub-system -*/
#define SDS_ATTR_TRIGGER_TYPE                   IVISCOPE_ATTR_TRIGGER_TYPE             /* ViInt32  */
#define SDS_ATTR_TRIGGER_SOURCE                 IVISCOPE_ATTR_TRIGGER_SOURCE           /* ViString */
#define SDS_ATTR_TRIGGER_LEVEL                  IVISCOPE_ATTR_TRIGGER_LEVEL            /* ViReal64, volts */
#define SDS_ATTR_TRIGGER_HOLDOFF                IVISCOPE_ATTR_TRIGGER_HOLDOFF          /* ViReal64, seconds   */
#define SDS_ATTR_TRIGGER_MODIFIER               IVISCOPE_ATTR_TRIGGER_MODIFIER         /* ViInt32 */
/*- Edge Trigger Attributes -*/
#define SDS_ATTR_TRIGGER_COUPLING               IVISCOPE_ATTR_TRIGGER_COUPLING         /* ViInt32 */
#define SDS_ATTR_TRIGGER_SLOPE                  IVISCOPE_ATTR_TRIGGER_SLOPE            /* ViInt32 */
/*- TV Trigger Attributes -*/
#define SDS_ATTR_TV_TRIGGER_SIGNAL_FORMAT       IVISCOPE_ATTR_TV_TRIGGER_SIGNAL_FORMAT /* ViInt32 */
#define SDS_ATTR_TV_TRIGGER_EVENT               IVISCOPE_ATTR_TV_TRIGGER_EVENT         /* ViInt32 */
#define SDS_ATTR_TV_TRIGGER_LINE_NUMBER         IVISCOPE_ATTR_TV_TRIGGER_LINE_NUMBER   /* ViInt32 */
#define SDS_ATTR_TV_TRIGGER_POLARITY            IVISCOPE_ATTR_TV_TRIGGER_POLARITY      /* ViInt32 */
/*- Runt Trigger Attributes -*/
#define SDS_ATTR_RUNT_HIGH_THRESHOLD            IVISCOPE_ATTR_RUNT_HIGH_THRESHOLD      /* ViReal64, volts */
#define SDS_ATTR_RUNT_LOW_THRESHOLD             IVISCOPE_ATTR_RUNT_LOW_THRESHOLD       /* ViReal64, volts */
#define SDS_ATTR_RUNT_POLARITY                  IVISCOPE_ATTR_RUNT_POLARITY            /* ViInt32 */
/*- Glitch Trigger Attributes -*/
#define SDS_ATTR_GLITCH_WIDTH                   IVISCOPE_ATTR_GLITCH_WIDTH             /* ViReal64, seconds */
#define SDS_ATTR_GLITCH_POLARITY                IVISCOPE_ATTR_GLITCH_POLARITY          /* ViInt32 */
#define SDS_ATTR_GLITCH_CONDITION               IVISCOPE_ATTR_GLITCH_CONDITION         /* ViInt32 */
/*- Width Trigger Attributes -*/
#define SDS_ATTR_WIDTH_CONDITION                IVISCOPE_ATTR_WIDTH_CONDITION          /* ViInt32   */
#define SDS_ATTR_WIDTH_HIGH_THRESHOLD           IVISCOPE_ATTR_WIDTH_HIGH_THRESHOLD     /* ViReal64, seconds */
#define SDS_ATTR_WIDTH_LOW_THRESHOLD            IVISCOPE_ATTR_WIDTH_LOW_THRESHOLD      /* ViReal64, seconds */
#define SDS_ATTR_WIDTH_POLARITY                 IVISCOPE_ATTR_WIDTH_POLARITY           /* ViInt32   */
/*- AC Line Trigger Attributes -*/
#define SDS_ATTR_AC_LINE_TRIGGER_SLOPE          IVISCOPE_ATTR_AC_LINE_TRIGGER_SLOPE    /* ViInt32*/
/*- Waveform Measurement Attributes -*/
#define SDS_ATTR_MEAS_HIGH_REF                  IVISCOPE_ATTR_MEAS_HIGH_REF            /* ViReal64, percentage */
#define SDS_ATTR_MEAS_LOW_REF                   IVISCOPE_ATTR_MEAS_LOW_REF             /* ViReal64, percentage */
#define SDS_ATTR_MEAS_MID_REF                   IVISCOPE_ATTR_MEAS_MID_REF             /* ViReal64, percentage */
/*- Other Specific Attributes -*/
#define SDS_ATTR_ID_QUERY_RESPONSE              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1L)     /* ViString (Read Only) */
#define SDS_ATTR_CHANNEL_LABLE_TEXT             (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 2L)
#define SDS_ATTR_INSTR_TRIGGER_EDGE_LEVEL       (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 3L)
#define SDS_ATTR_INSTR_TRIGGER_WIDTH_LEVEL      (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 4L)
#define SDS_ATTR_INSTR_TRIGGER_INTERVAL_LEVEL   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 5L)
#define SDS_ATTR_INSTR_TRIGGER_PATTERN_LEVEL    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 6L)
#define SDS_ATTR_INSTR_TRIGGER_DROPOUT_LEVEL    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 7L)
#define SDS_ATTR_INSTR_TRIGGER_TV_LEVEL         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 8L)
#define SDS_ATTR_INSTR_TRIGGER_GLITCH_LEVEL     (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 9L)
#define SDS_ATTR_INSTR_TRIGGER_EDGE_HOLDOFF     (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 10L)
#define SDS_ATTR_INSTR_TRIGGER_GLITCH_HOLDOFF   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 11L)
#define SDS_ATTR_INSTR_TRIGGER_INTERVAL_HOLDOFF (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 12L)
#define SDS_ATTR_INSTR_TRIGGER_PATTERN_HOLDOFF  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 13L)
#define SDS_ATTR_INSTR_TRIGGER_SLOPE_HOLDOFF    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 14L)
#define SDS_ATTR_INSTR_TRIGGER_RUNT_HOLDOFF     (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 15L)
#define SDS_ATTR_INSTR_TRIGGER_WINDOW_HOLDOFF   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 16L)
#define SDS_ATTR_INSTR_TRIGGER_DROPOUT_HOLDOFF  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 17L)
#define SDS_ATTR_MEASURE_ENABLED                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 18L)
#define SDS_ATTR_MEASURE_MODE                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 19L)
#define SDS_ATTR_MEASURE_GATE                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 20L)
#define SDS_ATTR_MEASURE_GATE_GA                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 21L)
#define SDS_ATTR_MEASURE_GATE_GB                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 22L)
#define SDS_ATTR_MEASURE_ADVANCED_STYLE         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 23L)
#define SDS_ATTR_MEASURE_ADVANCED_LINENUMBER    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 24L)
#define SDS_ATTR_MEASURE_ADVANCED_STATISTICS    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 25L)
#define SDS_ATTR_MEASURE_ADVANCED_STATISTICS_HISTOGRAM  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 26L)
#define SDS_ATTR_MEASURE_ADVANCED_STATISTICA_MAXCOUNT   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 27L)
#define SDS_ATTR_MEASURE_SIMPLE_SOURCE                  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 28L)
#define SDS_ATTR_MEASURE_ADVANCED_STATISTICS_RESET      (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 29L)
#define SDS_ATTR_INSTR_TRIGGER_EDGE_SOURCE              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 30L)
#define SDS_ATTR_INSTR_TRIGGER_GLITCH_SOURCE            (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 31L)
#define SDS_ATTR_INSTR_TRIGGER_WIDTH_SOURCE             (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 32L)
#define SDS_ATTR_INSTR_TRIGGER_INTERVAL_SOURCE          (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 33L)
#define SDS_ATTR_INSTR_TRIGGER_DROPOUT_SOURCE           (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 34L)
#define SDS_ATTR_INSTR_TRIGGER_TV_SOURCE                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 35L)
#define SDS_ATTR_INSTR_TRIGGER_RUNT_SOURCE              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 36L)
#define SDS_ATTR_INSTR_TRIGGER_SLOPE_SOURCE             (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 37L)
#define SDS_ATTR_INSTR_TRIGGER_WINDOW_SOURCE            (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 38L)
#define SDS_ATTR_INSTR_TRIGGER_LIN_SOURCE               (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 40L)
#define SDS_ATTR_INSTR_TRIGGER_CANFD_SOURCE             (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 41L)
#define SDS_ATTR_INSTR_TRIGGER_FLEXRAY_SOURCE           (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 42L)

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/
/*- SDS_ATTR_PROBE_ATTENUATION Values -*/
#define SDS_VAL_PROBE_SENSE_ON        IVISCOPE_VAL_PROBE_SENSE_ON

/*- SDS_ATTR_VERTICAL_COUPLING Values -*/
#define SDS_VAL_AC                    IVISCOPE_VAL_AC
#define SDS_VAL_DC                    IVISCOPE_VAL_DC
#define SDS_VAL_GND                   IVISCOPE_VAL_GND

/*- SDS_ATTR_TRIGGER_TYPE Values -*/
#define SDS_VAL_EDGE_TRIGGER          IVISCOPE_VAL_EDGE_TRIGGER
#define SDS_VAL_WIDTH_TRIGGER         IVISCOPE_VAL_WIDTH_TRIGGER
#define SDS_VAL_RUNT_TRIGGER          IVISCOPE_VAL_RUNT_TRIGGER
#define SDS_VAL_GLITCH_TRIGGER        IVISCOPE_VAL_GLITCH_TRIGGER
#define SDS_VAL_TV_TRIGGER            IVISCOPE_VAL_TV_TRIGGER
#define SDS_VAL_IMMEDIATE_TRIGGER     IVISCOPE_VAL_IMMEDIATE_TRIGGER
#define SDS_VAL_AC_LINE_TRIGGER       IVISCOPE_VAL_AC_LINE_TRIGGER

/*- SDS_ATTR_TRIGGER_SOURCE Values -*/
#define SDS_VAL_EXTERNAL              IVISCOPE_VAL_EXTERNAL
#define SDS_VAL_GPIB_GET              IVISCOPE_VAL_GPIB_GET
#define SDS_VAL_TTL0                  IVISCOPE_VAL_TTL0
#define SDS_VAL_TTL1                  IVISCOPE_VAL_TTL1
#define SDS_VAL_TTL2                  IVISCOPE_VAL_TTL2
#define SDS_VAL_TTL3                  IVISCOPE_VAL_TTL3
#define SDS_VAL_TTL4                  IVISCOPE_VAL_TTL4
#define SDS_VAL_TTL5                  IVISCOPE_VAL_TTL5
#define SDS_VAL_TTL6                  IVISCOPE_VAL_TTL6
#define SDS_VAL_TTL7                  IVISCOPE_VAL_TTL7
#define SDS_VAL_ECL0                  IVISCOPE_VAL_ECL0
#define SDS_VAL_ECL1                  IVISCOPE_VAL_ECL1
#define SDS_VAL_PXI_STAR              IVISCOPE_VAL_PXI_STAR
#define SDS_VAL_RTSI_0                IVISCOPE_VAL_RTSI_0
#define SDS_VAL_RTSI_1                IVISCOPE_VAL_RTSI_1
#define SDS_VAL_RTSI_2                IVISCOPE_VAL_RTSI_2
#define SDS_VAL_RTSI_3                IVISCOPE_VAL_RTSI_3
#define SDS_VAL_RTSI_4                IVISCOPE_VAL_RTSI_4
#define SDS_VAL_RTSI_5                IVISCOPE_VAL_RTSI_5
#define SDS_VAL_RTSI_6                IVISCOPE_VAL_RTSI_6

/*- SDS_ATTR_TRIGGER_MODIFIER Values -*/
#define SDS_VAL_NO_TRIGGER_MOD        IVISCOPE_VAL_NO_TRIGGER_MOD /* default */
#define SDS_VAL_AUTO                  IVISCOPE_VAL_AUTO
#define SDS_VAL_AUTO_LEVEL    /*unsupported by SDS2000X+*/        IVISCOPE_VAL_AUTO_LEVEL
#define SDS_VAL_SINGLE                      4

/*- SDS_ATTR_TRIGGER_COUPLING Values -*/
/* #define SDS_VAL_AC       IVISCOPE_VAL_AC     DEFINED ABOVE */
/* #define SDS_VAL_DC       IVISCOPE_VAL_DC     DEFINED ABOVE */
#define SDS_VAL_AC_TRIGGER            0 
#define SDS_VAL_DC_TRIGGER            1
#define SDS_VAL_LF_REJECT             IVISCOPE_VAL_LF_REJECT
#define SDS_VAL_HF_REJECT             IVISCOPE_VAL_HF_REJECT
#define SDS_VAL_NOISE_REJECT          IVISCOPE_VAL_NOISE_REJECT

/*- SDS_ATTR_TRIGGER_SLOPE Values -*/
#define SDS_VAL_POSITIVE              IVISCOPE_VAL_POSITIVE
#define SDS_VAL_NEGATIVE              IVISCOPE_VAL_NEGATIVE

/*- SDS_ATTR_TV_TRIGGER_SIGNAL_FORMAT Values -*/
#define SDS_VAL_NTSC                  IVISCOPE_VAL_NTSC
#define SDS_VAL_PAL                   IVISCOPE_VAL_PAL
#define SDS_VAL_SECAM     /*unsupported by SDS2000X+*/    IVISCOPE_VAL_SECAM
#define SDS_VAL_720P50                       4
#define SDS_VAL_720P60                       5
#define SDS_VAL_1080P50                      6
#define SDS_VAL_1080P60                      7
#define SDS_VAL_1080I50                      8
#define SDS_VAL_1080I60                      9
#define SDS_VAL_CUSTOM                       10

/*- SDS_ATTR_TV_TRIGGER_EVENT Values -*/
#define SDS_VAL_TV_EVENT_FIELD1             IVISCOPE_VAL_TV_EVENT_FIELD1
#define SDS_VAL_TV_EVENT_FIELD2             IVISCOPE_VAL_TV_EVENT_FIELD2
#define SDS_VAL_TV_EVENT_ANY_FIELD          IVISCOPE_VAL_TV_EVENT_ANY_FIELD
#define SDS_VAL_TV_EVENT_ANY_LINE           IVISCOPE_VAL_TV_EVENT_ANY_LINE
#define SDS_VAL_TV_EVENT_LINE_NUMBER        IVISCOPE_VAL_TV_EVENT_LINE_NUMBER
/*- other SDS_ATTR_TRIGGER_TYPE Values surpported by sds2000X+-*/
#define SDS_VAL_PATTERN_TRIGGER                                     8
#define SDS_VAL_QUALIFIED_TRIGGER                                   9
#define SDS_VAL_WINDOW_TRIGGER                                      10
#define SDS_VAL_INTERVAL_TRIGGER                                    11
#define SDS_VAL_DROPOUT_TRIGGER                                     12
#define SDS_VAL_IIC_TRIGGER                                         13
#define SDS_VAL_SPI_TRIGGER                                         14
#define SDS_VAL_UART_TRIGGER                                        15
#define SDS_VAL_LIN_TRIGGER                                         16
#define SDS_VAL_CAN_TRIGGER                                         17
#define SDS_VAL_FLEXRAY_TRIGGER                                     18
#define SDS_VAL_CANFD_TRIGGER                                       19
#define SDS_VAL_IIS_TRIGGER                                         20
#define SDS_VAL_SLOPE_TRIGGER                                       21
#define SDS_VAL_M1553_TRIGGER                                       22

/*- Defined values for SDS_ATTR_TV_TRIGGER_POLARITY -*/
#define SDS_VAL_TV_POSITIVE               IVISCOPE_VAL_TV_POSITIVE
#define SDS_VAL_TV_NEGATIVE               IVISCOPE_VAL_TV_NEGATIVE

/*- Defined values for SDS_ATTR_RUNT_POLARITY -*/
#define SDS_VAL_RUNT_POSITIVE             IVISCOPE_VAL_RUNT_POSITIVE
#define SDS_VAL_RUNT_NEGATIVE             IVISCOPE_VAL_RUNT_NEGATIVE
#define SDS_VAL_RUNT_EITHER               IVISCOPE_VAL_RUNT_EITHER

/*- Defined values for SDS_ATTR_GLITCH_CONDITION -*/
#define SDS_VAL_GLITCH_LESS_THAN          IVISCOPE_VAL_GLITCH_LESS_THAN
#define SDS_VAL_GLITCH_GREATER_THAN       IVISCOPE_VAL_GLITCH_GREATER_THAN

/*- Defined values for SDS_ATTR_GLITCH_POLARITY -*/
#define SDS_VAL_GLITCH_POSITIVE           IVISCOPE_VAL_GLITCH_POSITIVE
#define SDS_VAL_GLITCH_NEGATIVE           IVISCOPE_VAL_GLITCH_NEGATIVE
#define SDS_VAL_GLITCH_EITHER             IVISCOPE_VAL_GLITCH_EITHER

/*- Defined values for SDS_ATTR_WIDTH_CONDITION -*/
#define SDS_VAL_WIDTH_WITHIN              IVISCOPE_VAL_WIDTH_WITHIN
#define SDS_VAL_WIDTH_OUTSIDE             IVISCOPE_VAL_WIDTH_OUTSIDE

/*- Defined values for SDS_ATTR_WIDTH_POLARITY -*/
#define SDS_VAL_WIDTH_POSITIVE            IVISCOPE_VAL_WIDTH_POSITIVE
#define SDS_VAL_WIDTH_NEGATIVE            IVISCOPE_VAL_WIDTH_NEGATIVE

/*- Defined values for SDS_ATTR_AC_LINE_TRIGGER_SLOPE -*/
#define SDS_VAL_AC_LINE_POSITIVE          IVISCOPE_VAL_AC_LINE_POSITIVE
#define SDS_VAL_AC_LINE_NEGATIVE          IVISCOPE_VAL_AC_LINE_NEGATIVE
#define SDS_VAL_AC_LINE_EITHER            IVISCOPE_VAL_AC_LINE_EITHER

/*- SDS_ATTR_ACQUISITION_TYPE Values -*/
#define SDS_VAL_NORMAL                IVISCOPE_VAL_NORMAL     /* default */
#define SDS_VAL_PEAK_DETECT           IVISCOPE_VAL_PEAK_DETECT
#define SDS_VAL_HI_RES     /*unsupported by SDS2000X+*/           IVISCOPE_VAL_HI_RES
#define SDS_VAL_ENVELOPE   /*unsupported by SDS2000X+*/           IVISCOPE_VAL_ENVELOPE
#define SDS_VAL_AVERAGE    /*unsupported by SDS2000X+*/           IVISCOPE_VAL_AVERAGE

/*- SDS_ATTR_INTERPOLATION Values -*/
#define SDS_VAL_NO_INTERPOLATION      IVISCOPE_VAL_NO_INTERPOLATION   
#define SDS_VAL_SINE_X                IVISCOPE_VAL_SINE_X          /* default */
#define SDS_VAL_LINEAR                IVISCOPE_VAL_LINEAR         

/*- SDS_ATTR_SAMPLE_MODE Values -*/
#define SDS_VAL_REAL_TIME             IVISCOPE_VAL_REAL_TIME          
#define SDS_VAL_EQUIVALENT_TIME       IVISCOPE_VAL_EQUIVALENT_TIME

#define SDS_VAL_ALTERNATE                                           2
/*- SDS_ATTR_PROBE_ATTENUATION Values -*/
/*- You can use these three value macros to set probe attenuation as 1,10,100,
    and use a ViReal64 data type variable to set an arbitrary probe as well, like 10.1. -*/
#define SDS_VAL_PROBE_SENSE_1                                       1.000000
#define SDS_VAL_PROBE_SENSE_10                                      10.000000
#define SDS_VAL_PROBE_SENSE_100                                     100.000000

/*- SDS_ATTR_INPUT_IMPEDANCE Values -*/
#define SDS_VAL_IMPEDANCE_50                                        50
#define SDS_VAL_IMPEDANCE_1M                                        1000000
/*- SDS_ATTR_TRIGGER_HOLDOFF Values -*/
#define SDS_VAL_HOLDOFF_NONE                                         0
#define SDS_VAL_HOLDOFF_EVENTS                                      -1
#define SDS_VAL_HOLDOFF_TIME                                        -2

/*- SDS_ATTR_TRIGGER_SOURCE Values -*/
#define SDS_VAL_CHAN1                                "C1"
#define SDS_VAL_CHAN2                                "C2"
#define SDS_VAL_CHAN3                                "C3"
#define SDS_VAL_CHAN4                                "C4"
#define SDS_VAL_DIGIT0                               "D0"
#define SDS_VAL_DIGIT1                               "D1"
#define SDS_VAL_DIGIT2                               "D2"
#define SDS_VAL_DIGIT3                               "D3"
#define SDS_VAL_DIGIT4                               "D4"
#define SDS_VAL_DIGIT5                               "D5"
#define SDS_VAL_DIGIT6                               "D6"
#define SDS_VAL_DIGIT7                               "D7"
#define SDS_VAL_DIGIT8                               "D8"
#define SDS_VAL_DIGIT9                               "D9"
#define SDS_VAL_DIGIT10                              "D10"
#define SDS_VAL_DIGIT11                              "D11"
#define SDS_VAL_DIGIT12                              "D12"
#define SDS_VAL_DIGIT13                              "D13"
#define SDS_VAL_DIGIT14                              "D14"
#define SDS_VAL_DIGIT15                              "D15"
#define SDS_VAL_EX                                   "EX"
#define SDS_VAL_EX5                                  "EX5"
#define SDS_VAL_LINE                                 "LINE"

#define SDS_VAL_MEAS_MODE_SIMPLE                                    0
#define SDS_VAL_MEAS_MODE_ADVANCED                                  1

#define SDS_VAL_MEAS_ADV_STYLE_M1                                   0
#define SDS_VAL_MEAS_ADV_STYLE_M2                                   1

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
/*- Init and Close Functions -------------------------------------------*/
ViStatus _VI_FUNC  sds_init (ViRsrc resourceName, ViBoolean IDQuery,
                                  ViBoolean resetDevice, ViSession *vi);
ViStatus _VI_FUNC  sds_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                             ViBoolean resetDevice, ViConstString optionString,
                                             ViSession *newVi);
ViStatus _VI_FUNC  sds_close (ViSession vi);
/*- Locking Functions --------------------------------------------------*/
ViStatus _VI_FUNC  sds_LockSession (ViSession vi, ViBoolean *callerHasLock);
ViStatus _VI_FUNC  sds_UnlockSession (ViSession vi, ViBoolean *callerHasLock);
/*- STOP/RUN instrument ---------------------------------------------------*/
ViStatus _VI_FUNC  sds_Abort (ViSession vi);
ViStatus _VI_FUNC sds_Continue (ViSession vi);
/*- Auto Setup, RUN instrument-----------------------------------------*/
ViStatus _VI_FUNC  sds_AutoSetup (ViSession vi);
/*- Utility Functions --------------------------------------------------*/
ViStatus _VI_FUNC  sds_reset (ViSession vi);
ViStatus _VI_FUNC  sds_ResetWithDefaults (ViSession vi);

/*- Acquisition Subsystem Configuration ---------------------------------*/
ViStatus _VI_FUNC  sds_ConfigureAcquisitionType (ViSession vi,
                                                      ViInt32 acquisitionType);
ViStatus _VI_FUNC  sds_ConfigureAcquisitionRecord (ViSession vi, 
                                                        ViReal64 timePerRecord, 
                                                        ViInt32 minimumRecordLength,
                                                        ViReal64 acqStartTime); /* minimumRecordLength unsupported by SDS2000X+. 
                                                                                    You can enter an arbitrary value*/

ViStatus _VI_FUNC  sds_ConfigureNumAverages (ViSession vi,
                                                  ViInt32 numberOfAverages);
ViStatus _VI_FUNC  sds_ConfigureInterpolation (ViSession vi,
                                                    ViInt32 interpolation);
ViStatus _VI_FUNC  sds_SampleRate (ViSession vi, ViReal64 *sampleRate);
ViStatus _VI_FUNC  sds_ActualRecordLength (ViSession vi, 
                                                ViInt32 *actualRecordLength);
ViStatus _VI_FUNC  sds_ConfigureInitiateContinuous (ViSession vi, 
                                                         ViBoolean continuous);

/*- Channel Info Functions ---------------------------------------------*/
ViStatus _VI_FUNC sds_GetChannelName (ViSession vi, ViInt32 index, 
                                   ViInt32 bufferSize, ViChar name[]);
/*- Channel Subsystem Configuration -------------------------------------*/
ViStatus _VI_FUNC  sds_ConfigureChannel (ViSession vi,
                                              ViConstString channel,
                                              ViReal64 range,
                                              ViReal64 offset, 
                                              ViInt32 coupling,
                                              ViReal64 probeAttenuation,
                                              ViBoolean enabled);
ViStatus _VI_FUNC sds_ConfigureChanCharacteristics (ViSession vi,
                                                         ViConstString channel,
                                                         ViReal64 inputImpedance,
                                                         ViReal64 maxInputFrequency);
ViStatus _VI_FUNC sds_AutoProbeSenseValue (ViSession vi,
                                                ViConstString channel,
                                                ViReal64 *autoProbeSenseValue);

/*- Triggering Subsystem Configuration ----------------------------------*/
ViStatus _VI_FUNC  sds_ConfigureTrigger (ViSession vi, 
                                              ViInt32 triggerType, 
                                              ViReal64 holdoff);
ViStatus _VI_FUNC  sds_ConfigureTriggerCoupling (ViSession vi,
                                                      ViInt32 coupling);
ViStatus _VI_FUNC  sds_ConfigureTriggerModifier (ViSession vi, 
                                                      ViInt32 modifier);
ViStatus _VI_FUNC  sds_ConfigureEdgeTriggerSource (ViSession vi, 
                                                        ViConstString source,
                                                        ViReal64 level, 
                                                        ViInt32 slope);
ViStatus _VI_FUNC sds_ConfigureTVTriggerSource (ViSession vi,
                                                     ViConstString source, 
                                                     ViInt32 TVSignalFormat,
                                                     ViInt32 TVEvent,
                                                     ViInt32 TVPolarity);
ViStatus _VI_FUNC sds_ConfigureTVTriggerLineNumber (ViSession vi,
                                                         ViInt32 lineNumber);
ViStatus _VI_FUNC sds_ConfigureRuntTriggerSource (ViSession vi,
                                                       ViConstString source,
                                                       ViReal64 runtLowThreshold,
                                                       ViReal64 runtHighThreshold,
                                                       ViInt32 runtPolarity);
ViStatus _VI_FUNC sds_ConfigureGlitchTriggerSource (ViSession vi,
                                                         ViConstString source,
                                                         ViReal64 level,
                                                         ViReal64 glitchWidth,
                                                         ViInt32 glitchPolarity,
                                                         ViInt32 glitchCondition);
ViStatus _VI_FUNC sds_ConfigureWidthTriggerSource (ViSession vi,
                                                        ViConstString source,
                                                        ViReal64 level,
                                                        ViReal64 widthLowThreshold,
                                                        ViReal64 widthHighThreshold,
                                                        ViInt32 widthPolarity,
                                                        ViInt32 widthCondition);
/*- Waveform Acquisition ---------------------------------------*/
ViStatus _VI_FUNC  sds_ReadWaveform (ViSession vi, 
                                          ViConstString channel,
                                          ViInt32 waveformSize,
                                          ViInt32 maxTime,
                                          ViReal64 waveform[],
                                          ViInt32 *actualPoints, 
                                          ViReal64 *initialX,
                                          ViReal64 *xIncrement);
ViStatus _VI_FUNC  sds_FetchWaveform (ViSession vi,
                                           ViConstString channel,
                                           ViInt32 waveformSize,
                                           ViReal64 waveform[],
                                           ViInt32 *actualPoints,
                                           ViReal64 *initialX,
                                           ViReal64 *xIncrement);
/***************************************************************************
* DESCRIPTION for sds_self_test():
*       You can set VI_NULL for 3rd parameter.
*       SDS2000X+ oscilloscope will return you a value store in selfTestResult.
******************************************************************************/
ViStatus _VI_FUNC  sds_self_test (ViSession vi, ViInt16 *selfTestResult,
                                       ViChar selfTestMessage[]);
ViStatus _VI_FUNC  sds_revision_query (ViSession vi,
                                            ViChar instrumentDriverRevision[],
                                            ViChar firmwareRevision[]);

/****************************************************************************
 *---------- Set, Get, and Check Attribute Functions ------------*
 ****************************************************************************/
ViStatus _VI_FUNC  sds_GetAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 *value);
ViStatus _VI_FUNC  sds_GetAttributeViInt64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt64 *value);
ViStatus _VI_FUNC  sds_GetAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 *value);
ViStatus _VI_FUNC  sds_GetAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 bufSize, ViChar value[]);
ViStatus _VI_FUNC  sds_GetAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession *value);
ViStatus _VI_FUNC  sds_GetAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean *value);

ViStatus _VI_FUNC  sds_SetAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 value);
ViStatus _VI_FUNC  sds_SetAttributeViInt64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt64 value);
ViStatus _VI_FUNC  sds_SetAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 value);
ViStatus _VI_FUNC  sds_SetAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViConstString value);
ViStatus _VI_FUNC  sds_SetAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession value);
ViStatus _VI_FUNC  sds_SetAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean value);

ViStatus _VI_FUNC  sds_CheckAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 value);
ViStatus _VI_FUNC  sds_CheckAttributeViInt64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt64 value);
ViStatus _VI_FUNC  sds_CheckAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 value);
ViStatus _VI_FUNC  sds_CheckAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViConstString value);
ViStatus _VI_FUNC  sds_CheckAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession value);
ViStatus _VI_FUNC  sds_CheckAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean value);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/
#define SDS_WARN_INVALID_WFM_ELEMENT              IVISCOPE_WARN_INVALID_WFM_ELEMENT

#define SDS_ERROR_CHANNEL_NOT_ENABLED             IVISCOPE_ERROR_CHANNEL_NOT_ENABLED
#define SDS_ERROR_UNABLE_TO_PERFORM_MEASUREMENT   IVISCOPE_ERROR_UNABLE_TO_PERFORM_MEASUREMENT
#define SDS_ERROR_INVALID_ACQ_TYPE                IVISCOPE_ERROR_INVALID_ACQ_TYPE
#define SDS_ERROR_MAX_TIME_EXCEEDED               IVISCOPE_ERROR_MAX_TIME_EXCEEDED

/****************************************************************************
 *----- Macros unsupported by sds.dll but defined in IVI specificaton----*
 ****************************************************************************/
/* Defined values for maxTime parameter to the waveform acquisition functions */
#define SDS_VAL_MAX_TIME_INFINITE         IVISCOPE_VAL_MAX_TIME_INFINITE
#define SDS_VAL_MAX_TIME_IMMEDIATE        IVISCOPE_VAL_MAX_TIME_IMMEDIATE

/* Defined values for the status parameter of the sds_Acquisition_Status function */
#define SDS_VAL_ACQ_COMPLETE          IVISCOPE_VAL_ACQ_COMPLETE       
#define SDS_VAL_ACQ_IN_PROGRESS       IVISCOPE_VAL_ACQ_IN_PROGRESS    
#define SDS_VAL_ACQ_STATUS_UNKNOWN    IVISCOPE_VAL_ACQ_STATUS_UNKNOWN

/****************************************************************************************
 *----- Functions unsupported by sds.dll but defined by IVI specificaton----*
 ****************************************************************************************/
ViStatus _VI_FUNC  sds_AcquisitionStatus (ViSession vi, ViInt32 *status);/*unsupported*/

/* Used when SDS_ATTR_ACQUISTION_TYPE is either: SDS_VAL_PEAK_DETECT or SDS_VAL_ENVELOPE */
ViStatus _VI_FUNC  sds_ReadMinMaxWaveform (ViSession vi,
                                                ViConstString channel, 
                                                ViInt32 waveformSize,
                                                ViInt32 maxTime,
                                                ViReal64 minWaveform[],
                                                ViReal64 maxWaveform[],
                                                ViInt32 *actualPoints,
                                                ViReal64 *initialX, 
                                                ViReal64 *xIncrement);/*unsupported*/

/* Used when SDS_ATTR_ACQUISTION_TYPE is either: SDS_VAL_PEAK_DETECT or SDS_VAL_ENVELOPE */
ViStatus _VI_FUNC  sds_FetchMinMaxWaveform (ViSession vi,
                                                 ViConstString channel, 
                                                 ViInt32 waveformSize,
                                                 ViReal64 minWaveform[], 
                                                 ViReal64 maxWaveform[],
                                                 ViInt32 *actualPoints, 
                                                 ViReal64 *initialX,
                                                 ViReal64 *xIncrement);/*unsupported*/
                                    
/*- Waveform Measurements ----------------------------------------------*/
ViStatus _VI_FUNC  sds_ConfigureRefLevels (ViSession vi,
                                                ViReal64 lowRef, 
                                                ViReal64 midRef,
                                                ViReal64 highRef);/*unsupported*/
ViStatus _VI_FUNC  sds_ReadWaveformMeasurement (ViSession vi,
                                                     ViConstString channel, 
                                                     ViInt32 measurementFunction,
                                                     ViInt32 maxTime, 
                                                     ViReal64 *measurement);/*unsupported*/
ViStatus _VI_FUNC  sds_FetchWaveformMeasurement (ViSession vi,
                                                      ViConstString channel, 
                                                      ViInt32 measurementFunction, 
                                                      ViReal64 *measurement);/*unsupported*/

ViStatus _VI_FUNC  sds_SampleMode (ViSession vi, ViInt32 *sampleMode);/*unsupported*/

/*- Coercion Info Functions --------------------------------------------*/
ViStatus _VI_FUNC  sds_GetNextCoercionRecord (ViSession vi,
                                                   ViInt32 bufferSize,
                                                   ViChar record[]);/*unsupported*/
ViStatus _VI_FUNC  sds_InitiateAcquisition (ViSession vi);/*unsupported*/
ViStatus _VI_FUNC  sds_ConfigureNumEnvelopes (ViSession vi,
                                                   ViInt32 numberOfEnvelopes);/*unsupported*/
ViStatus _VI_FUNC sds_ConfigureAcLineTriggerSlope (ViSession vi, 
                                                        ViInt32 acLineSlope);/*unsupported*/
ViStatus _VI_FUNC  sds_Disable (ViSession vi);/*unsupported*/
/* Obsolete Direct IO Functions. */
ViStatus _VI_FUNC  sds_viWrite (ViSession vi, ViByte buffer[], ViInt64 count, ViInt64 *returnCount);/*unsupported*/
ViStatus _VI_FUNC  sds_viRead (ViSession vi, ViInt64 bufferSize, ViByte buffer[], ViInt64 *returnCount);/*unsupported*/
ViStatus _VI_FUNC  sds_WriteInstrData (ViSession vi, ViConstString writeBuffer); /*unsupported*/
ViStatus _VI_FUNC  sds_ReadInstrData  (ViSession vi, ViInt32 numBytes, 
                                            ViChar rdBuf[], ViInt32 *bytesRead);/*unsupported*/
ViStatus _VI_FUNC sds_InvalidateAllAttributes (ViSession vi);/*unsupported*/

/*- Interchangeability Checking Functions ------------------------------*/
ViStatus _VI_FUNC sds_GetNextInterchangeWarning (ViSession vi,
                                                      ViInt32 bufferSize,
                                                      ViChar warnString[]);/*unsupported*/
ViStatus _VI_FUNC sds_ResetInterchangeCheck (ViSession vi);/*unsupported*/
ViStatus _VI_FUNC sds_ClearInterchangeWarnings (ViSession vi);/*unsupported*/
ViStatus _VI_FUNC sds_IsInvalidWfmElement (ViSession vi, ViReal64 elementValue, 
                                                    ViBoolean *isInvalid);/*unsupported*/
/*- Error Functions ----------------------------------------------------*/
ViStatus _VI_FUNC  sds_error_query (ViSession vi, ViInt32 *errorCode,
                                         ViChar errorMessage[]);/*unsupported*/
ViStatus _VI_FUNC  sds_GetError (ViSession vi, ViStatus *code,
                                      ViInt32 bufferSize, ViChar description[]);/*unsupported*/
ViStatus _VI_FUNC  sds_ClearError (ViSession vi);/*unsupported*/
ViStatus _VI_FUNC  sds_error_message (ViSession vi, ViStatus errorCode,
                                           ViChar errorMessage[256]);/*unsupported*/

/*-----------------------------------------------------------------------
*- IVI Inherent Instrument Attributes ----------------------------------*
-----------------------------------------------------------------------*/
/*- User Options -*/
#define SDS_ATTR_RANGE_CHECK                                IVI_ATTR_RANGE_CHECK                    /* ViBoolean */
#define SDS_ATTR_QUERY_INSTRUMENT_STATUS                    IVI_ATTR_QUERY_INSTRUMENT_STATUS        /* ViBoolean */
#define SDS_ATTR_CACHE                                      IVI_ATTR_CACHE                          /* ViBoolean */
#define SDS_ATTR_SIMULATE                                   IVI_ATTR_SIMULATE                       /* ViBoolean */
#define SDS_ATTR_RECORD_COERCIONS                           IVI_ATTR_RECORD_COERCIONS               /* ViBoolean */
#define SDS_ATTR_INTERCHANGE_CHECK                          IVI_ATTR_INTERCHANGE_CHECK              /* ViBoolean */
/*- Driver Information -*/
#define SDS_ATTR_SPECIFIC_DRIVER_PREFIX                     IVI_ATTR_SPECIFIC_DRIVER_PREFIX         /* ViString, read-only  */
#define SDS_ATTR_SUPPORTED_INSTRUMENT_MODELS                IVI_ATTR_SUPPORTED_INSTRUMENT_MODELS    /* ViString, read-only  */
#define SDS_ATTR_GROUP_CAPABILITIES                         IVI_ATTR_GROUP_CAPABILITIES             /* ViString, read-only  */
#define SDS_ATTR_INSTRUMENT_MANUFACTURER                    IVI_ATTR_INSTRUMENT_MANUFACTURER        /* ViString, read-only  */
#define SDS_ATTR_INSTRUMENT_MODEL                           IVI_ATTR_INSTRUMENT_MODEL               /* ViString, read-only  */
#define SDS_ATTR_INSTRUMENT_FIRMWARE_REVISION               IVI_ATTR_INSTRUMENT_FIRMWARE_REVISION              /* ViString, read-only  */
#define SDS_ATTR_SPECIFIC_DRIVER_REVISION                   IVI_ATTR_SPECIFIC_DRIVER_REVISION       /* ViString, read-only  */
#define SDS_ATTR_SPECIFIC_DRIVER_VENDOR                     IVI_ATTR_SPECIFIC_DRIVER_VENDOR         /* ViString, read-only  */
#define SDS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                IVI_ATTR_SPECIFIC_DRIVER_DESCRIPTION    /* ViString, read-only  */
#define SDS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION   IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION /* ViInt32, read-only */
#define SDS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION   IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION /* ViInt32, read-only */
/*- Advanced Session Information -*/
#define SDS_ATTR_LOGICAL_NAME                               IVI_ATTR_LOGICAL_NAME                   /* ViString, read-only  */
#define SDS_ATTR_IO_RESOURCE_DESCRIPTOR                     IVI_ATTR_IO_RESOURCE_DESCRIPTOR         /* ViString, read-only  */
#define SDS_ATTR_DRIVER_SETUP                               IVI_ATTR_DRIVER_SETUP                   /* ViString, read-only  */
/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/
#define SDS_VAL_RISE_TIME                 IVISCOPE_VAL_RISE_TIME
#define SDS_VAL_FALL_TIME                 IVISCOPE_VAL_FALL_TIME
#define SDS_VAL_FREQUENCY                 IVISCOPE_VAL_FREQUENCY
#define SDS_VAL_PERIOD                    IVISCOPE_VAL_PERIOD
#define SDS_VAL_VOLTAGE_RMS               IVISCOPE_VAL_VOLTAGE_RMS
#define SDS_VAL_VOLTAGE_PEAK_TO_PEAK      IVISCOPE_VAL_VOLTAGE_PEAK_TO_PEAK
#define SDS_VAL_VOLTAGE_MAX               IVISCOPE_VAL_VOLTAGE_MAX
#define SDS_VAL_VOLTAGE_MIN               IVISCOPE_VAL_VOLTAGE_MIN
#define SDS_VAL_VOLTAGE_HIGH              IVISCOPE_VAL_VOLTAGE_HIGH
#define SDS_VAL_VOLTAGE_LOW               IVISCOPE_VAL_VOLTAGE_LOW
#define SDS_VAL_VOLTAGE_AVERAGE           IVISCOPE_VAL_VOLTAGE_AVERAGE
#define SDS_VAL_WIDTH_NEG                 IVISCOPE_VAL_WIDTH_NEG
#define SDS_VAL_WIDTH_POS                 IVISCOPE_VAL_WIDTH_POS
#define SDS_VAL_DUTY_CYCLE_NEG            IVISCOPE_VAL_DUTY_CYCLE_NEG
#define SDS_VAL_DUTY_CYCLE_POS            IVISCOPE_VAL_DUTY_CYCLE_POS
#define SDS_VAL_AMPLITUDE                 IVISCOPE_VAL_AMPLITUDE
#define SDS_VAL_VOLTAGE_CYCLE_RMS         IVISCOPE_VAL_VOLTAGE_CYCLE_RMS
#define SDS_VAL_VOLTAGE_CYCLE_AVERAGE     IVISCOPE_VAL_VOLTAGE_CYCLE_AVERAGE
#define SDS_VAL_OVERSHOOT                 IVISCOPE_VAL_OVERSHOOT
#define SDS_VAL_PRESHOOT                  IVISCOPE_VAL_PRESHOOT

#define SDS_VAL_NEW_FUNCTION   IVISCOPE_VAL_CALCULATION_SPECIFIC_DRIVER_BASE + 1
/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/
#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __SDS_HEADER */

